@@ -32,10 +32,10 @@
 
 G_BEGIN_DECLS
 
-void fm_turn_on_desktop_icons();
+void fm_turn_on_desktop_icons( gboolean transparent );
 void fm_turn_off_desktop_icons();
 void fm_desktop_update_thumbnails();
-void fm_desktop_update_wallpaper();
+void fm_desktop_update_wallpaper( gboolean transparency_changed );
 void fm_desktop_update_colors();
 void fm_desktop_update_icons();
 void fm_desktop_set_single_click( gboolean single_click );
