@@ -44,6 +44,7 @@
 #include "ptk-app-chooser.h"
 #include "ptk-file-properties.h"
 #include "ptk-file-menu.h"
+#include "ptk-location-view.h"
 
 #include "find-files.h"
 #include "pref-dialog.h"
@@ -167,7 +168,6 @@ static void get_socket_name( char* buf, int len );
 static gboolean on_socket_event( GIOChannel* ioc, GIOCondition cond, gpointer data );
 
 static void init_folder();
-static void init_daemon_or_desktop();
 static void check_icon_theme();
 
 static gboolean handle_parsed_commandline_args();
@@ -761,6 +761,7 @@ void show_socket_help()
     printf( "sort_case                       1|true|yes|0|false|no\n" );
     printf( "sort_hidden_first               1|true|yes|0|false|no\n" );
     printf( "sort_first                      files|folders|mixed\n" );
+    printf( "large_icons                     1|true|yes|0|false|no\n" );
     printf( "statusbar_text                  %s\n", _("eg 'Current Status: Example'") );
     printf( "pathbar_text                    [TEXT [SELSTART [SELEND]]]\n" );
     printf( "current_dir                     %s\n", _("DIR            eg '/etc'") );
@@ -799,6 +800,8 @@ void show_socket_help()
     printf( "delete [--dir DIR] FILE|DIR...  %s\n", _("Recursively delete FILE(s) or DIR(s)" ) );
     printf( "edit [--as-root] FILE           %s\n", _("Open FILE in user's or root's text editor") );
     printf( "web URL                         %s\n", _("Open URL in user's web browser") );
+    printf( "mount DEVICE|URL                %s\n", _("Mount DEVICE or URL") );
+    printf( "unmount DEVICE|DIR              %s\n", _("Unmount DEVICE or mount point DIR") );
 
     printf( "\n%s\n", _("EVENTS\n------") );
     printf( "evt_start                       %s\n", _("Instance start        %e") );
@@ -842,7 +845,7 @@ void show_socket_help()
     printf( "    spacefm -s show-menu --window $fm_my_window \"Custom Menu\"\n" );
     printf( "    spacefm -s add-event evt_pnl_sel 'spacefm -s set statusbar_text \"$fm_file\"'\n\n" );
     
-    printf( "    #!/bin/bash\n" );
+    printf( "    #!%s\n", BASHPATH );
     printf( "    eval copied_files=\"$(spacefm -s get clipboard_copy_files)\"\n" );
     printf( "    echo \"%s:\"\n", _("These files have been copied to the clipboard") );
     printf( "    i=0\n" );
@@ -945,12 +948,6 @@ void init_folder()
     folder_initialized = TRUE;
 }
 
-static void init_daemon_or_desktop()
-{
-    if( desktop )
-        fm_turn_on_desktop_icons();
-}
-
 #ifdef HAVE_HAL
 
 /* FIXME: Currently, this cannot be supported without HAL */
@@ -1009,8 +1006,9 @@ static void init_desktop_or_daemon()
     signal( SIGINT, (void*)gtk_main_quit );
     signal( SIGTERM, (void*)gtk_main_quit );
 
-    if( desktop )
-        fm_turn_on_desktop_icons();
+    if ( desktop )
+        fm_turn_on_desktop_icons( app_settings.show_wallpaper == 1 &&
+                            app_settings.wallpaper_mode == WPM_TRANSPARENT );
     desktop_or_deamon_initialized = TRUE;
 }
 
@@ -1126,6 +1124,7 @@ gboolean handle_parsed_commandline_args()
     gboolean ret = TRUE;
     XSet* set;
     int p;
+    struct stat64 statbuf;
 
     app_settings.load_saved_tabs = !no_tabs;
     
@@ -1146,15 +1145,17 @@ gboolean handle_parsed_commandline_args()
     }
 
     if ( desktop_pref )  //MOD
+    {
+#ifdef DESKTOP_INTEGRATION
         show_pref = 3;
-
+#else
+        show_pref = 1;
+        fprintf( stderr, "spacefm: %s\n", _("This build of SpaceFM has desktop integration disabled") );
+#endif
+    }
+    
     if( show_pref > 0 ) /* show preferences dialog */
     {
-        /* We should initialize desktop support here.
-         * Otherwise, if the user turn on the desktop support
-         * in the pref dialog, the newly loaded desktop will be uninitialized.
-         */
-        //init_desktop_or_daemon();
         fm_edit_preference( GTK_WINDOW( main_window ), show_pref - 1 );
         show_pref = 0;
     }
@@ -1195,13 +1196,13 @@ gboolean handle_parsed_commandline_args()
             if( desktop && app_settings.show_wallpaper )
             {
                 if( desktop_or_deamon_initialized )
-                    fm_desktop_update_wallpaper();
+                    fm_desktop_update_wallpaper( FALSE );
             }
         }
         else
             g_free( file );
 
-        ret = ( daemon_mode || ( desktop && desktop_or_deamon_initialized)  );
+        ret = ( daemon_mode || ( desktop && desktop_or_deamon_initialized ) );
         goto out;
     }
 #endif
@@ -1228,7 +1229,24 @@ gboolean handle_parsed_commandline_args()
                     ret = TRUE;
                 }
                 else if ( g_file_test( real_path, G_FILE_TEST_EXISTS ) )
-                    open_file( real_path );
+                {
+                    if ( stat64( real_path, &statbuf ) == 0 &&
+                                            S_ISBLK( statbuf.st_mode ) )
+                    {
+                        // open block device eg /dev/sda1
+                        if ( !main_window )
+                        {
+                            open_in_tab( &main_window, "/" );
+                            ptk_location_view_open_block( real_path, FALSE );
+                        }
+                        else
+                            ptk_location_view_open_block( real_path, TRUE );
+                        ret = TRUE;
+                        gtk_window_present( GTK_WINDOW( main_window ) );
+                    }
+                    else
+                        open_file( real_path );
+                }
                 else if ( ( *file[0] != '/' && strstr( *file, ":/" ) )
                                         || g_str_has_prefix( *file, "//" ) )
                 {
@@ -1338,7 +1356,9 @@ int main ( int argc, char *argv[] )
                 vfs_file_monitor_clean();
                 return ret == -1 ? 0 : ret;
             }
+            GDK_THREADS_ENTER();
             gtk_main();
+            GDK_THREADS_LEAVE();
             vfs_file_monitor_clean();
             return 0;
         }
@@ -1428,10 +1448,12 @@ int main ( int argc, char *argv[] )
     }
     
     // bash installed?
-    if ( !g_file_test( "/bin/\x62\x61\x73\x68", G_FILE_TEST_IS_EXECUTABLE ) )
+    if ( !( BASHPATH && g_file_test( BASHPATH, G_FILE_TEST_IS_EXECUTABLE ) ) )
     {
-        fprintf( stderr, "spacefm: %s\n", _("SpaceFM requires genuine /bin/\x62\x61\x73\x68 (v4+) to be installed.  Other shells are NOT equivalent.") );
-        ptk_show_error( NULL, _("Error"), _("SpaceFM requires genuine /bin/\x62\x61\x73\x68 (v4+) to be installed.  Other shells are NOT equivalent.") );
+        char* bash_error = g_strdup_printf( _( "SpaceFM requires bash to be installed.  Other shells are NOT equivalent as SpaceFM uses features only found in genuine bash (v4+).\n\nThe program %s was not found.  Install bash or use configure option --with-bash-path to specify a custom location at build time." ), BASHPATH );
+        fprintf( stderr, "spacefm: %s\n", bash_error );
+        ptk_show_error( NULL, _("Error"), bash_error );
+        g_free( bash_error );
         return 1;
     }
 
@@ -1498,8 +1520,10 @@ int main ( int argc, char *argv[] )
     run = handle_parsed_commandline_args();
     app_settings.load_saved_tabs = TRUE;
 
+    GDK_THREADS_ENTER();
     if( run )   /* run the main loop */
         gtk_main();
+    GDK_THREADS_LEAVE();
 
     main_window_event( NULL, NULL, "evt_exit", 0, 0, NULL, 0, 0, 0, FALSE );
 
@@ -1591,7 +1615,8 @@ void open_file( const char* path )
         else
             error_msg = _( "Don't know how to open the file" );
         disp_path = g_filename_display_name( path );
-        msg = g_strdup_printf( _( "Unable to open file:\n\"%s\"\n%s" ), disp_path, error_msg );
+        msg = g_strdup_printf( _( "Unable to open file:\n\"%s\"\n%s" ),
+                                                disp_path, error_msg );
         g_free( disp_path );
         ptk_show_error( NULL, _("Error"), msg );
         g_free( msg );
