@@ -11,12 +11,16 @@
 // this determines time before item is selected by hover in single-click mode
 #define SINGLE_CLICK_TIMEOUT 150
 
+// This limits the small icon size for side panes and task list
+#define PANE_MAX_ICON_SIZE 48
+
 typedef enum {
     WPM_STRETCH,
     WPM_FULL,
     WPM_CENTER,
     WPM_TILE,
-    WPM_ZOOM
+    WPM_ZOOM,
+    WPM_TRANSPARENT
 }WallpaperMode;
 
 typedef struct
@@ -366,11 +370,13 @@ XSet* xset_get_plugin_mirror( XSet* set );
 void write_src_functions( FILE* file );
 char* xset_custom_get_script( XSet* set, gboolean create );
 gboolean have_rw_access( const char* path );
+gboolean have_x_access( const char* path );
 char* xset_get_keyname( XSet* set, int key_val, int key_mod );
 void xset_set_key( GtkWidget* parent, XSet* set );
 
 XSet* xset_set( const char* name, const char* var, const char* value );
 XSet* xset_set_set( XSet* set, const char* var, const char* value );
+void xset_custom_delete( XSet* set, gboolean delete_next );
 void xset_add_menu( DesktopWindow* desktop, PtkFileBrowser* file_browser,
                     GtkWidget* menu, GtkAccelGroup *accel_group, char* elements );
 GtkWidget* xset_add_menuitem( DesktopWindow* desktop, PtkFileBrowser* file_browser,
